# {qualname}

[[[Source]]]({source_link})

{import_statement}

```{{eval-rst}}
.. automodule:: {qualname_no_alias}
  :no-members:
```

## All symbols

{all_symbols_table}


```{{toctree}}
:hidden:

{toctree}
```
